==> jc-1.4.0.tar.gz: java/rmi/activation/UnknownObjectException.h <==
// public class java.rmi.activation.UnknownObjectException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class fd8995a120b8f60d java_rmi_activation_ActivationException
// @dep_class b8cf5bef375c015c java_rmi_activation_UnknownObjectException

// header file dependencies
// @dep_header java_rmi_activation_ActivationException

#include "java/rmi/activation/ActivationException.h"

#ifndef _JC_java_rmi_activation_UnknownObjectException_H_
#define _JC_java_rmi_activation_UnknownObjectException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_rmi_activation_UnknownObjectException$sub_refs	_jc_java_rmi_activation_UnknownObjectException$sub_refs;
typedef struct _jc_java_rmi_activation_UnknownObjectException$sub_nonrefs	_jc_java_rmi_activation_UnknownObjectException$sub_nonrefs;
typedef struct _jc_java_rmi_activation_UnknownObjectException$refs	_jc_java_rmi_activation_UnknownObjectException$refs;
typedef struct _jc_java_rmi_activation_UnknownObjectException$nonrefs	_jc_java_rmi_activation_UnknownObjectException$nonrefs;
typedef struct _jc_java_rmi_activation_UnknownObjectException$object	_jc_java_rmi_activation_UnknownObjectException$object;

typedef struct _jc_java_rmi_activation_UnknownObjectException$fields_struct	_jc_java_rmi_activation_UnknownObjectException$fields_struct;
typedef const struct _jc_java_rmi_activation_UnknownObjectException$vmethods	_jc_java_rmi_activation_UnknownObjectException$vmethods;
typedef const struct _jc_java_rmi_activation_UnknownObjectException$vtable	_jc_java_rmi_activation_UnknownObjectException$vtable;
typedef const struct _jc_java_rmi_activation_UnknownObjectException$vtype	_jc_java_rmi_activation_UnknownObjectException$vtype;

// Class fields structure
struct _jc_java_rmi_activation_UnknownObjectException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_rmi_activation_UnknownObjectException$fields_struct _jc_java_rmi_activation_UnknownObjectException$class_fields;

// Constructors
extern void _jc_java_rmi_activation_UnknownObjectException$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_rmi_activation_UnknownObjectException$object *, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_java_rmi_activation_UnknownObjectException$vmethods {
};

// Vtable
struct _jc_java_rmi_activation_UnknownObjectException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_rmi_activation_ActivationException$vmethods	java_rmi_activation_ActivationException;
	_jc_java_rmi_activation_UnknownObjectException$vmethods	java_rmi_activation_UnknownObjectException;
};

// Vtype
struct _jc_java_rmi_activation_UnknownObjectException$vtype {
	_jc_type			type;
	_jc_java_rmi_activation_UnknownObjectException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_rmi_activation_UnknownObjectException$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_rmi_activation_UnknownObjectException$refs {
    _jc_java_rmi_activation_UnknownObjectException$sub_refs	java_rmi_activation_UnknownObjectException;
    _jc_java_rmi_activation_ActivationException$sub_refs	java_rmi_activation_ActivationException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_rmi_activation_UnknownObjectException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_rmi_activation_UnknownObjectException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_rmi_activation_ActivationException$sub_nonrefs	java_rmi_activation_ActivationException;
    _jc_java_rmi_activation_UnknownObjectException$sub_nonrefs	java_rmi_activation_UnknownObjectException;
};

// Object instance structure
struct _jc_java_rmi_activation_UnknownObjectException$object {
	_jc_java_rmi_activation_UnknownObjectException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_rmi_activation_UnknownObjectException$vtype	*vtype;
	_jc_java_rmi_activation_UnknownObjectException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_rmi_activation_UnknownObjectException$vtype _jc_java_rmi_activation_UnknownObjectException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_rmi_activation_UnknownObjectException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_rmi_activation_UnknownObjectException$class_object;

#endif	/* _JC_java_rmi_activation_UnknownObjectException_H_ */

==> jc-1.4.6.tar.gz: java/rmi/activation/UnknownObjectException.h <==
// public class java.rmi.activation.UnknownObjectException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class fd8995a120b8f60d java_rmi_activation_ActivationException
// @dep_class b8cf5bef375c015c java_rmi_activation_UnknownObjectException

// header file dependencies
// @dep_header java_rmi_activation_ActivationException

#include "java/rmi/activation/ActivationException.h"

#ifndef _JC_java_rmi_activation_UnknownObjectException_H_
#define _JC_java_rmi_activation_UnknownObjectException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_rmi_activation_UnknownObjectException$sub_refs	_jc_java_rmi_activation_UnknownObjectException$sub_refs;
typedef struct _jc_java_rmi_activation_UnknownObjectException$sub_nonrefs	_jc_java_rmi_activation_UnknownObjectException$sub_nonrefs;
typedef struct _jc_java_rmi_activation_UnknownObjectException$refs	_jc_java_rmi_activation_UnknownObjectException$refs;
typedef struct _jc_java_rmi_activation_UnknownObjectException$nonrefs	_jc_java_rmi_activation_UnknownObjectException$nonrefs;
typedef struct _jc_java_rmi_activation_UnknownObjectException$object	_jc_java_rmi_activation_UnknownObjectException$object;

typedef struct _jc_java_rmi_activation_UnknownObjectException$fields_struct	_jc_java_rmi_activation_UnknownObjectException$fields_struct;
typedef const struct _jc_java_rmi_activation_UnknownObjectException$vmethods	_jc_java_rmi_activation_UnknownObjectException$vmethods;
typedef const struct _jc_java_rmi_activation_UnknownObjectException$vtable	_jc_java_rmi_activation_UnknownObjectException$vtable;
typedef const struct _jc_java_rmi_activation_UnknownObjectException$vtype	_jc_java_rmi_activation_UnknownObjectException$vtype;

// Class fields structure
struct _jc_java_rmi_activation_UnknownObjectException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_rmi_activation_UnknownObjectException$fields_struct _jc_java_rmi_activation_UnknownObjectException$class_fields;

// Constructors
extern void _jc_java_rmi_activation_UnknownObjectException$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_rmi_activation_UnknownObjectException$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_rmi_activation_UnknownObjectException$vmethods {
};

// Vtable
struct _jc_java_rmi_activation_UnknownObjectException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_rmi_activation_ActivationException$vmethods	java_rmi_activation_ActivationException;
	_jc_java_rmi_activation_UnknownObjectException$vmethods	java_rmi_activation_UnknownObjectException;
};

// Vtype
struct _jc_java_rmi_activation_UnknownObjectException$vtype {
	_jc_type			type;
	_jc_java_rmi_activation_UnknownObjectException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_rmi_activation_UnknownObjectException$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_rmi_activation_UnknownObjectException$refs {
    _jc_java_rmi_activation_UnknownObjectException$sub_refs	java_rmi_activation_UnknownObjectException;
    _jc_java_rmi_activation_ActivationException$sub_refs	java_rmi_activation_ActivationException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_rmi_activation_UnknownObjectException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_rmi_activation_UnknownObjectException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_rmi_activation_ActivationException$sub_nonrefs	java_rmi_activation_ActivationException;
    _jc_java_rmi_activation_UnknownObjectException$sub_nonrefs	java_rmi_activation_UnknownObjectException;
};

// Object instance structure
struct _jc_java_rmi_activation_UnknownObjectException$object {
	_jc_java_rmi_activation_UnknownObjectException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_rmi_activation_UnknownObjectException$vtype	*vtype;
	_jc_java_rmi_activation_UnknownObjectException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_rmi_activation_UnknownObjectException$vtype _jc_java_rmi_activation_UnknownObjectException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_rmi_activation_UnknownObjectException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_rmi_activation_UnknownObjectException$class_object;

#endif	/* _JC_java_rmi_activation_UnknownObjectException_H_ */
